/*
  This file is part of the KDE libraries
  Copyright (c) 2005 Willem Verschuur <willverschuur@yahoo.com>
  Copyright (c) 2006 Helio Chissini de Castro <helio@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/

#ifndef KCONFIGLDAPBACKEND_H
#define KCONFIGLDAPBACKEND_H

#include "kconfigbackend.h"

/**
 * Class for KDE INI-style configuration file loading/saving from LDAP
 *
 * @author Willem Verschuur <willverschuur@yahoo.com>
 * @author Helio Chissini de Castro <helio@kde.org>
 */

class KDECORE_EXPORT KConfigLDAPBackEnd : public KConfigBackEnd
{
   public:
      KConfigLDAPBackEnd( KConfigBase *_config, const QString &_fileName, const char * _resType, bool _useKDEGlobals = true );
      virtual ~KConfigLDAPBackEnd();
      bool parseConfigFiles();
      virtual void sync(bool bMerge = true);
      inline void setFileImmutable( bool mt ) { _fileImmutable = mt; }
      inline bool getFileImmutable() { return _fileImmutable; }
      inline void setGroupImmutable( QString str, bool mt ) { _groupImmutable[ str ] = mt; }
      QMap< QString, bool > getGroupImmutable() { return _groupImmutable; }

   protected:
      virtual void virtual_hook(int id, void* data);
      bool _fileImmutable;
      QMap< QString, bool > _groupImmutable;
};

#endif

